@@ -7,11 +7,10 @@
 module Control.Exception.IOChoice.Lifted where
 
 import Control.Exception (IOException)
-import Control.Exception.Lifted (catch, throwIO)
+import qualified Control.Exception.Lifted as L (catch, throwIO)
 import Control.Monad.Base (MonadBase)
 import Control.Monad.IO.Class
 import Control.Monad.Trans.Control (MonadBaseControl)
-import Prelude hiding (catch)
 
 -- |
 -- If 'IOException' occurs or 'goNext' is used in the left monad,
@@ -19,13 +18,13 @@ import Prelude hiding (catch)
 -- throws 'IOException'.
 
 (||>) :: MonadBaseControl IO m => m a -> m a -> m a
-x ||> y = x `catch` (\(_ :: IOException) -> y)
+x ||> y = x `L.catch` (\(_ :: IOException) -> y)
 
-infixl 3 ||>
+infixr 3 ||>
 
 -- | Go to the next 'IO' monad by throwing 'IOException'.
 goNext :: (MonadIO m, MonadBase IO m) => m a
-goNext = throwIO $ userError "goNext for lifted IO"
+goNext = L.throwIO $ userError "goNext for lifted IO"
 
 -- | Run any one lifted 'IO' monad.
 runAnyOne :: (MonadIO m, MonadBaseControl IO m) => [m a] -> m a
